{% extends "base.html" %}

{% block title %}{% if filetitle %}{{ filetitle }}{% endif %}{% endblock %}

{%- block styles -%}
  {%- for style_path in style_paths -%}
  <link rel="stylesheet" href="{{ style_path }}" />
  {% endfor -%}
  {%- if styles %}
  <style>
    {% for style in styles -%}
    {{ style }}
    {% endfor -%}
  </style>
  {% endif -%}
  <style>
    .file-box {
      margin: 64px auto;
      width: 920px;
    }
	body {
		font-size: 14px;
		line-height: 22px;
		<!--font-family: "adelle",Georgia,"Times New Roman",serif;-->
		color: #4e443c;
		background: #f0efe7;
	}

	.book-toc {

	}
	a {
		color: #0388a6;
		text-decoration: none;
	}
	a:hover {
		color: #04b1d8;
		text-decoration: none;
	}
	ol.book-toc li.chapter{
		margin-bottom:0.6em
	}
	ol.book-toc, ol{
		list-style-type: disc
	}
	ol.book-toc{
		margin:30px 36px
	}
	ol.book-toc a{
		padding-left:4px
	}
	li {
		line-height: 22px;
	}
	h1, h2, h3, h4, h5, h6, li, p, a, ol, div{
		margin: 0;
		padding: 0;
		border: 0;
		vertical-align: baseline;
	}
	ul, ol {
		padding: 0;
		margin: 0 0 11px 25px;
	}
	h1 {
		font-size: 36px;
		line-height: 44px;
		margin-bottom: 0.4em;
	}
	h2 {
		font-size: 18px;
		color: #f14e32;
		font-weight: bold;
	}
	h3, h4, h5, h6 {
		font-size: 14px;
		color: #f14e32;
		font-weight: bold;
	}
	ol.book-toc h1{
		font-size: 22px;
		line-height: 44px;
		margin-bottom: 0.4em;
	}
	ol.book-toc h2 {
		font-size: 16px;
		color: #f14e32;
		font-weight: bold;
	}
	ol.book-toc h3, h4, h5, h6 {
		font-size: 14px;
		color: #f14e32;
		font-weight: bold;
	}
	p {
		margin: 0 0 11px;
		font-size: 14px;
		line-height: 22px;
	}
	div {
		display: block;
	}
	div#nav{
		padding: 30px
	}
  </style>
{%- endblock -%}

{%- block page -%}
  <div class="file-box">
	<div class="file">
		<div id="readme" class="blob instapaper_body announce md">
		  <article class="markdown-body entry-content" itemprop="mainContentOfPage">
			{{ content|safe }}
		  </article>
		  {% if needtoc %}
			<div id="nav">
				{% if prevfile %}
					<a href="{{ prevfile }}">prev</a>
					{% if nextfile -%}
						|
					{%- endif %}
				{% endif %}
				{% if nextfile %}
					<a href="{{ nextfile }}">next</a>
				{% endif %}
				<span style="float: right"><a href="index.html">Back to home</a>
			</div>
		  {% endif %}
		</div>
	</div>
  </div>
  
  <div>&nbsp;</div>
{%- endblock -%}
