STYLE_URLS = []
STYLE_URLS_SOURCE = "https://github.com/marchtea/md_to_github_html"
STYLE_URLS_RE = '<link.+href=[\'"]?([^\'" >]+)[\'"]?.+media=[\'"]?(?:screen|all)[\'"]?.+rel=[\'"]?stylesheet[\'"]?.+/>'
